<?php

namespace Litecms\Comapnydata\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Comapnydata\Models\CompanyData;

class CompanyDataPolicy
{

    /**
     * Determine if the given user can view the company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function view(UserPolicy $user, CompanyData $company_data)
    {
        if ($user->canDo('comapnydata.company_data.view') && $user->isAdmin()) {
            return true;
        }

        return $company_data->user_id == user_id() && $company_data->user_type == user_type();
    }

    /**
     * Determine if the given user can create a company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('comapnydata.company_data.create');
    }

    /**
     * Determine if the given user can update the given company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function update(UserPolicy $user, CompanyData $company_data)
    {
        if ($user->canDo('comapnydata.company_data.edit') && $user->isAdmin()) {
            return true;
        }

        return $company_data->user_id == user_id() && $company_data->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, CompanyData $company_data)
    {
        return $company_data->user_id == user_id() && $company_data->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function verify(UserPolicy $user, CompanyData $company_data)
    {
        if ($user->canDo('comapnydata.company_data.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given company_data.
     *
     * @param UserPolicy $user
     * @param CompanyData $company_data
     *
     * @return bool
     */
    public function approve(UserPolicy $user, CompanyData $company_data)
    {
        if ($user->canDo('comapnydata.company_data.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
