<?php

namespace Litecms\Comapnydata\Providers;

use Illuminate\Support\ServiceProvider;

class ComapnydataServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'comapnydata');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'comapnydata');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.comapnydata', function ($app) {
            return $this->app->make('Litecms\Comapnydata\Comapnydata');
        });

                // Bind CompanyData to repository
        $this->app->bind(
            'Litecms\Comapnydata\Interfaces\CompanyDataRepositoryInterface',
            \Litecms\Comapnydata\Repositories\Eloquent\CompanyDataRepository::class
        );

        $this->app->register(\Litecms\Comapnydata\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Comapnydata\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Comapnydata\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.comapnydata'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/comapnydata.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/comapnydata')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/comapnydata')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
