<?php

namespace Litecms\Comapnydatum\Providers;

use Illuminate\Support\ServiceProvider;

class ComapnydatumServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'comapnydatum');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'comapnydatum');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.comapnydatum', function ($app) {
            return $this->app->make('Litecms\Comapnydatum\Comapnydatum');
        });

                // Bind CompanyData to repository
        $this->app->bind(
            'Litecms\Comapnydatum\Interfaces\CompanyDataRepositoryInterface',
            \Litecms\Comapnydatum\Repositories\Eloquent\CompanyDataRepository::class
        );

        $this->app->register(\Litecms\Comapnydatum\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Comapnydatum\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Comapnydatum\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.comapnydatum'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/comapnydatum.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/comapnydatum')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/comapnydatum')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
